@@ -15,13 +15,15 @@
 `stackdriver.py`
 Stackdriver Monitoring backend implementation.
 """
-from collections import OrderedDict
 import logging
 import pprint
 import warnings
+from collections import OrderedDict
 
 from google.cloud import monitoring_v3
 
+from slo_generator.constants import NO_DATA
+
 LOGGER = logging.getLogger(__name__)
 
 
@@ -34,7 +36,6 @@ class StackdriverBackend:
             Existing Stackdriver Service Monitoring client. Initialize a new
             client if omitted.
     """
-
     def __init__(self, project_id, client=None):
         self.client = client
         if client is None:
@@ -80,7 +81,8 @@ class StackdriverBackend:
             valid_ts = list(valid_ts)
             bad_event_count = SD.count(valid_ts) - good_event_count
         else:
-            raise Exception("Oneof `filter_bad` or `filter_valid` is required.")
+            raise Exception(
+                "Oneof `filter_bad` or `filter_valid` is required.")
 
         LOGGER.debug(f'Good events: {good_event_count} | '
                      f'Bad events: {bad_event_count}')
@@ -111,7 +113,7 @@ class StackdriverBackend:
         series = list(series)
 
         if not series:
-            return (0, 0)  # no timeseries
+            return (NO_DATA, NO_DATA)  # no timeseries
 
         distribution_value = series[0].points[0].value.distribution_value
         # bucket_options = distribution_value.bucket_options
@@ -156,7 +158,7 @@ class StackdriverBackend:
         """
         warnings.warn(
             'exponential_distribution_cut will be deprecated in version 2.0, '
-            'please use distribution_cut instead', PendingDeprecationWarning)
+            'please use distribution_cut instead', FutureWarning)
         return self.distribution_cut(*args, **kwargs)
 
     def query(self,
@@ -206,8 +208,8 @@ class StackdriverBackend:
             return timeseries[0].points[0].value.int64_value
         except (IndexError, AttributeError) as exception:
             LOGGER.warning("Couldn't find any values in timeseries response")
-            LOGGER.debug(exception)
-            return 0  # no events in timeseries
+            LOGGER.debug(exception, exc_info=True)
+            return NO_DATA  # no events in timeseries
 
     @staticmethod
     def get_window(timestamp, window):
